import { __decorate, __metadata } from 'tslib';
import { ɵɵdefineInjectable, ɵɵinject, Injectable, EventEmitter, Component, NgModule } from '@angular/core';
import { NgxCvbspAuthorToolService, NgxCvbspAuthorToolModule } from '@vlemaitre/ngx-cvbsp-author-tool';
import { MatDialog } from '@angular/material/dialog';
import { NgxCvbspUploaderDialogComponent, NgxCvbspUploaderModule } from '@vlemaitre/ngx-cvbsp-uploader';
import { Multilang, NgxCvbspPlayerModule } from 'ngx-cvbsp-player';
import { CommonModule } from '@angular/common';
import { FormsModule } from '@angular/forms';
import { NgxContenteditableModule } from '@vlemaitre/ngx-contenteditable';
import { MatButtonModule } from '@angular/material/button';
import { MatCheckboxModule } from '@angular/material/checkbox';
import { MatTooltipModule } from '@angular/material/tooltip';

let NgxPlayerVideoCreateService = class NgxPlayerVideoCreateService {
    constructor(authorToolService) {
        this.authorToolService = authorToolService;
        this.setTranslations();
    }
    setTranslations() {
        this.authorToolService.translations.fr.NgxPlayerVideoComponent = 'Vidéo';
        this.authorToolService.translations.fr.REPLACE_VIDEO = 'Remplacer la vidéo';
        this.authorToolService.translations.fr.VIDEO_WIDTH = 'Largeur de la vidéo (% ou px)';
        this.authorToolService.translations.fr.VIDEO_HEIGHT = 'Hauteur de la vidéo (% ou px)';
        this.authorToolService.translations.fr.SHOW_INTRO = 'Montrer l\'introduction';
        this.authorToolService.translations.fr.NEXT_WHEN_FINISHED = 'Passer à la suite dès que la vidéo est terminée';
        this.authorToolService.translations.fr.AUTOPLAY = 'Lancer automatiquement la vidéo';
    }
};
NgxPlayerVideoCreateService.ctorParameters = () => [
    { type: NgxCvbspAuthorToolService }
];
NgxPlayerVideoCreateService.ɵprov = ɵɵdefineInjectable({ factory: function NgxPlayerVideoCreateService_Factory() { return new NgxPlayerVideoCreateService(ɵɵinject(NgxCvbspAuthorToolService)); }, token: NgxPlayerVideoCreateService, providedIn: "root" });
NgxPlayerVideoCreateService = __decorate([
    Injectable({
        providedIn: 'root'
    }),
    __metadata("design:paramtypes", [NgxCvbspAuthorToolService])
], NgxPlayerVideoCreateService);

let NgxPlayerVideoCreateComponent = class NgxPlayerVideoCreateComponent {
    constructor(service, dialog) {
        this.service = service;
        this.dialog = dialog;
        this.changeEvent = new EventEmitter();
        this.onUploaded = result => {
            if (result) {
                this.data.videoUrls[this.lang] = result.externalUrl;
                this.data.videoTypes[this.lang] = 'video/mp4';
                this.changeEvent.next(this.data);
            }
        };
    }
    ngOnInit() {
        this.data.intro = this.data.intro ? this.data.intro : { keep: null, fr: 'Votre intro', en: 'This is your intro' };
        this.data.title = this.data.title ? this.data.title : { keep: null, fr: 'Titre', en: 'Title' };
        this.data.videoHeights = this.data.videoHeights ? this.data.videoHeights : { keep: null, fr: '', en: '240' };
        this.data.videoTypes = this.data.videoTypes ? this.data.videoTypes : new Multilang();
        this.data.videoWidths = this.data.videoWidths ? this.data.videoWidths : { keep: null, fr: '100%', en: '100%' };
        this.data.videoUrls = this.data.videoUrls ? this.data.videoUrls : new Multilang();
    }
    inputChange() {
        this.changeEvent.next(this.data);
    }
    openUploaderDialog(replace) {
        if (!this.service.urlToUpload) {
            alert('you need to add an url to upload video in the config of the module, check the readme');
            return;
        }
        const dialogRef = this.dialog.open(NgxCvbspUploaderDialogComponent, {
            width: '500px',
            data: {
                restrictedExtensions: ['mp4'],
                closeOnUpload: true,
                urlToUpload: this.service.urlToUpload
            },
        });
        dialogRef.afterClosed().subscribe(this.onUploaded);
    }
};
NgxPlayerVideoCreateComponent.ctorParameters = () => [
    { type: NgxPlayerVideoCreateService },
    { type: MatDialog }
];
NgxPlayerVideoCreateComponent = __decorate([
    Component({
        // tslint:disable-next-line:component-selector
        selector: 'ngx-player-video-create',
        template: "<div class=\"cvbsp-video-container\" *ngIf=\"data\">\n  <div class=\"no-video\" *ngIf=\"!data.videoUrls[lang]\">     \n    <ngx-cvbsp-uploader \n      [restrictedExtensions]=\"['mp4']\"\n      [urlToUpload]=\"service.urlToUpload\"\n      (itemUploadedEvent)=\"onUploaded($event)\" \n      ></ngx-cvbsp-uploader>\n  </div>\n  <video *ngIf=\"data.videoUrls[lang]\" id=\"video\" #videoPlayer controls=\"controls\" preload=\"metadata\"\n  webkit-playsinline=\"webkit-playsinline\" class=\"video-player\">\n    <source \n    [src]=\"data.videoUrls[lang]\" \n    [type]=\"data.videoTypes[lang]\" />\n  </video>\n  <br/>\n  <button *ngIf=\"data.videoUrls[lang]\" mat-button (click)=\"openUploaderDialog(true)\">\n    {{ 'REPLACE_VIDEO' | translate }}\n  </button>\n  <br/><br/>\n  <div [contenteditable]=\"true\" (change)=\"inputChange()\" [(ngModel)]=\"data.title[lang]\" class=\"cvbsp-video-title\" *ngIf=\"data.hideTitle !== true\">\n  </div><br/>\n  \n  <html-box [(html)]=\"data.intro[lang]\"  *ngIf=\"data?.showIntro\"\n          [placeholder]=\"'CLICK_TO_EDIT' | translate\"></html-box>\n</div>\n<br/>\n<a class=\"adv-params-link\" (click)=\"showAdvancedParameters = !showAdvancedParameters\">\n  <span>{{ (showAdvancedParameters ? 'HIDE_ADVANCED_PARAMETERS' : 'SHOW_ADVANCED_PARAMETERS') | translate }} </span>\n</a>\n<br/><br/>\n<div *ngIf=\"showAdvancedParameters\" class=\"adv-params\">\n  <mat-checkbox  [(ngModel)]=\"data.autoplay\">\n    {{ 'AUTOPLAY' | translate }}\n  </mat-checkbox><br/>\n  <mat-checkbox  [(ngModel)]=\"data.nextWhenFinished\">\n    {{ 'NEXT_WHEN_FINISHED' | translate }}\n  </mat-checkbox><br/>\n  {{ 'VIDEO_WIDTH' | translate }} :\n  <input class=\"input-title\" \n    name=\"width-text\"\n    (change)=\"inputChange()\" \n    [(ngModel)]=\"data.videoWidths[lang]\">\n  <br/>\n  {{ 'VIDEO_HEIGHT' | translate }} :\n  <input class=\"input-title\" \n    name=\"width-text\"\n    (change)=\"inputChange()\" \n    [(ngModel)]=\"data.videoHeights[lang]\">\n    <br/><br/>\n  <mat-checkbox  [(ngModel)]=\"data.hideTitle\">\n    {{ 'HIDE_TITLE' | translate }}\n  </mat-checkbox><br/>\n  <mat-checkbox  [(ngModel)]=\"data.showIntro\" >\n    {{ 'SHOW_INTRO' | translate }}\n  </mat-checkbox><br/>\n  <div  class=\"block-box\" >\n    <mat-checkbox \n    [indeterminate]=\"data.noNext === null || data.noNext === undefined\" \n    class=\"checkbox-header\" [(ngModel)]=\"data.noNext\" \n    [matTooltip]=\"'NO_NEXT_TP' | translate\">\n      {{ 'NO_NEXT' | translate }}\n    </mat-checkbox>\n    <br/>\n    <input class=\"input-title\" \n    *ngIf=\"!data.noNext\"\n    name=\"next-text\"\n    placeholder=\"{{ 'NEXT_LABEL' | translate }}\"\n    (change)=\"inputChange()\" \n    [(ngModel)]=\"data.nextLabel[lang]\">\n  </div>\n  <div  class=\"block-box\" >\n      <mat-checkbox \n      [indeterminate]=\"data.noBack === null || data.noBack === undefined\" \n      class=\"checkbox-header\" [(ngModel)]=\"data.noBack\" \n      [matTooltip]=\"'NO_BACK_TP' | translate\">\n        {{ 'NO_BACK' | translate }}\n      </mat-checkbox><br/>\n      <input *ngIf=\"!data.noBack\"\n      class=\"input-title\" \n      placeholder=\"{{ 'BACK_LABEL' | translate }}\"\n      name=\"back-text\"\n      (change)=\"inputChange()\" \n      [(ngModel)]=\"data.backLabel[lang]\">\n  </div> \n  <div  class=\"block-box\" >\n</div> \n</div>\n",
        styles: ["video{outline:0}.cvbsp-video-container{text-align:center}.cvbsp-video-title{font-size:20px;color:#888}.back-btn{float:left}.cvbsp-video-actions{position:absolute;width:100%;padding:5px;bottom:0}.cvbsp-video-intro{padding:10px}.no-video{display:inline-block}.input-size{border:none;width:30px;height:40px;outline:0}.input-title{border:none;width:200px;height:40px;outline:0}.adv-params-link{font-weight:700;cursor:pointer}"]
    }),
    __metadata("design:paramtypes", [NgxPlayerVideoCreateService,
        MatDialog])
], NgxPlayerVideoCreateComponent);

let NgxPlayerVideoCreateModule = class NgxPlayerVideoCreateModule {
};
NgxPlayerVideoCreateModule = __decorate([
    NgModule({
        declarations: [NgxPlayerVideoCreateComponent],
        imports: [
            CommonModule,
            FormsModule,
            NgxCvbspPlayerModule,
            NgxCvbspAuthorToolModule,
            NgxContenteditableModule,
            NgxCvbspUploaderModule,
            MatButtonModule,
            MatCheckboxModule,
            MatTooltipModule
        ],
        exports: [NgxPlayerVideoCreateComponent],
        entryComponents: [NgxPlayerVideoCreateComponent]
    })
], NgxPlayerVideoCreateModule);

/*
 * Public API Surface of ngx-player-video-create
 */

/**
 * Generated bundle index. Do not edit.
 */

export { NgxPlayerVideoCreateComponent, NgxPlayerVideoCreateModule, NgxPlayerVideoCreateService };
//# sourceMappingURL=ngx-player-video-create.js.map
